@@ -2,6 +2,7 @@
 from rezbuild.builder import CompileBuilder
 from rezbuild.builder import ExtractBuilder
 from rezbuild.builder import InstallBuilder
+from rezbuild.builder import MacOSDmgBuilder
 from rezbuild.builder import PythonBuilder
 from rezbuild.builder import PythonSourceBuilder
 from rezbuild.builder import PythonWheelBuilder
@@ -12,6 +13,7 @@ __all__ = [
     "CompileBuilder",
     "ExtractBuilder",
     "InstallBuilder",
+    "MacOSDmgBuilder",
     "PythonBuilder",
     "PythonSourceBuilder",
     "PythonWheelBuilder",
